==> apollo-client-2.0.36-sources.jar: cn/com/duiba/apollo/client/service/ApolloAccessTokenService.java <==
package cn.com.duiba.apollo.client.service;

import cn.com.duiba.apollo.client.ApolloClientProperties;
import cn.com.duiba.apollo.client.dto.AccessTokenDTO;
import cn.com.duiba.apollo.client.params.ResourceAccessTokenParams;
import cn.com.duiba.apollo.client.remoteservice.RemoteResourceAccessTokenService;
import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.wolf.utils.NetUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.aspectj.lang.annotation.AfterThrowing;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicReference;

/**
 * @author liuyao
 */
@Aspect
@Slf4j
public class ApolloAccessTokenService {

    private volatile Long sceneId;

    @Resource
    private ApolloClientProperties apolloClientProperties;
    @Resource
    private RemoteResourceAccessTokenService remoteResourceAccessTokenService;

    private AtomicReference<String> reference = new AtomicReference<>();

    @AfterThrowing(value="execution(* cn.com.duiba.apollo.client.remoteservice.RemoteResourceAccessTokenService.verifyAccessToken(..))",throwing="throwable")
    public void afterThrowing(Throwable throwable){
        if(throwable instanceof BizException){
            log.error("accessToken验证失败"+reference.get(),throwable);
            flashAccessToken();
        }
    }

    public String getAccessToken(){
        if(StringUtils.isBlank(reference.get())){
            flashAccessToken();
        }
        if(StringUtils.isBlank(reference.get())){
            throw new RuntimeException("未能获取到accessToken");
        }
        return reference.get();
    }

    public Long getSceneId(){
        if(Objects.isNull(sceneId)){
            try{
                sceneId = remoteResourceAccessTokenService.verifyAccessToken(getAccessToken());
            }catch (Exception e){
                log.error("校验场景id失败",e);
            }
        }
        return sceneId;
    }

    @Scheduled(cron = "0 0 0/1 * * ?")
    public void autoFlushAccessToken(){
        if(StringUtils.isBlank(reference.get())){
            return;
        }
        flashAccessToken();
    }

    private synchronized void flashAccessToken(){
        if(StringUtils.isBlank(apolloClientProperties.getAccessKey()) || StringUtils.isBlank(apolloClientProperties.getAccessSecret())){
            return;
        }
        ResourceAccessTokenParams params = new ResourceAccessTokenParams();
        params.setAccessKey(apolloClientProperties.getAccessKey());
        params.setAccessSecret(apolloClientProperties.getAccessSecret());
        params.setIp(NetUtils.getLocalIp());

        try{
            AccessTokenDTO accessTokenDTO = remoteResourceAccessTokenService.acquireAccessToken(params);
            String accessToken = reference.getAndSet(accessTokenDTO.getAccessToken());
            if(StringUtils.isNotBlank(accessToken)){
                remoteResourceAccessTokenService.deleteAccessToken(accessToken);
            }
        }catch (BizException e){
            log.error("获取accessToken失败",e);
            reference.set(null);
        }
    }

}

==> apollo-client-2.0.43-sources.jar: cn/com/duiba/apollo/client/service/ApolloAccessTokenService.java <==
package cn.com.duiba.apollo.client.service;

import cn.com.duiba.apollo.client.ApolloClientProperties;
import cn.com.duiba.apollo.client.dto.AccessTokenDTO;
import cn.com.duiba.apollo.client.params.ResourceAccessTokenParams;
import cn.com.duiba.apollo.client.remoteservice.RemoteResourceAccessTokenService;
import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.wolf.utils.NetUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.aspectj.lang.annotation.AfterThrowing;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicReference;

/**
 * @author liuyao
 */
@Aspect
@Slf4j
public class ApolloAccessTokenService {

    @Resource
    private ApolloClientProperties apolloClientProperties;
    @Resource
    private RemoteResourceAccessTokenService remoteResourceAccessTokenService;

    private final AtomicReference<String> reference = new AtomicReference<>();

    @AfterThrowing(value="execution(* cn.com.duiba.apollo.client.remoteservice.RemoteResourceAccessTokenService.verifyAccessToken(..))",throwing="throwable")
    public void afterThrowing(Throwable throwable){
        if(throwable instanceof BizException){
            log.error("accessToken验证失败"+reference.get(),throwable);
            flashAccessToken();
        }
    }

    public String getAccessToken(){
        if(!apolloClientProperties.isStartResourceApi()){
            throw new RuntimeException("未配置accessKey和accessSecret,无法获取AccessToken");
        }
        if(StringUtils.isBlank(reference.get())){
            flashAccessToken();
        }
        if(StringUtils.isBlank(reference.get())){
            throw new RuntimeException("未能获取到accessToken");
        }
        return reference.get();
    }

    @Scheduled(cron = "0 0 0/1 * * ?")
    public void autoFlushAccessToken(){
        if(StringUtils.isBlank(reference.get())){
            return;
        }
        flashAccessToken();
    }

    private synchronized void flashAccessToken(){
        if(StringUtils.isBlank(apolloClientProperties.getAccessKey()) || StringUtils.isBlank(apolloClientProperties.getAccessSecret())){
            return;
        }
        ResourceAccessTokenParams params = new ResourceAccessTokenParams();
        params.setAccessKey(apolloClientProperties.getAccessKey());
        params.setAccessSecret(apolloClientProperties.getAccessSecret());
        params.setIp(NetUtils.getLocalIp());

        try{
            AccessTokenDTO accessTokenDTO = remoteResourceAccessTokenService.acquireAccessToken(params);
            String accessToken = reference.getAndSet(accessTokenDTO.getAccessToken());
            if(StringUtils.isNotBlank(accessToken)){
                remoteResourceAccessTokenService.deleteAccessToken(accessToken);
            }
        }catch (BizException e){
            log.error("获取accessToken失败",e);
            reference.set(null);
        }
    }

}
